@@ -2,7 +2,6 @@
 import io
 import pytest
 import re
-import uuid
 
 from collections import namedtuple
 from unittest import mock
@@ -121,25 +120,173 @@ def test_delete(mock_delete, capsys):
 @mock.patch('toot.http.get')
 def test_timeline(mock_get, monkeypatch, capsys):
     mock_get.return_value = MockResponse([{
+        'id': '111111111111111111',
         'account': {
-            'display_name': 'Frank Zappa',
-            'username': 'fz'
+            'display_name': 'Frank Zappa 🎸',
+            'acct': 'fz'
         },
         'created_at': '2017-04-12T15:53:18.174Z',
         'content': "<p>The computer can&apos;t tell you the emotional story. It can give you the exact mathematical design, but what's missing is the eyebrows.</p>",
         'reblog': None,
+        'in_reply_to_id': None,
+        'media_attachments': [],
     }])
 
-    console.run_command(app, user, 'timeline', [])
+    console.run_command(app, user, 'timeline', ['--once'])
 
-    mock_get.assert_called_once_with(app, user, '/api/v1/timelines/home')
+    mock_get.assert_called_once_with(app, user, '/api/v1/timelines/home?limit=10', None)
 
     out, err = capsys.readouterr()
-    assert "The computer can't tell you the emotional story." in out
-    assert "but what's missing is the eyebrows." in out
+    lines = out.split("\n")
+
+    assert "Frank Zappa 🎸" in lines[1]
+    assert "@fz" in lines[1]
+    assert "2017-04-12 15:53" in lines[1]
+
+    assert (
+        "The computer can't tell you the emotional story. It can give you the "
+        "exact mathematical design, but\nwhat's missing is the eyebrows." in out)
+
+    assert "111111111111111111" in lines[-3]
+
+    assert err == ""
+
+
+@mock.patch('toot.http.get')
+def test_timeline_with_re(mock_get, monkeypatch, capsys):
+    mock_get.return_value = MockResponse([{
+        'id': '111111111111111111',
+        'created_at': '2017-04-12T15:53:18.174Z',
+        'account': {
+            'display_name': 'Frank Zappa',
+            'acct': 'fz'
+        },
+        'reblog': {
+            'account': {
+                'display_name': 'Johnny Cash',
+                'acct': 'jc'
+            },
+            'content': "<p>The computer can&apos;t tell you the emotional story. It can give you the exact mathematical design, but what's missing is the eyebrows.</p>",
+            'media_attachments': [],
+        },
+        'in_reply_to_id': '111111111111111110',
+        'media_attachments': [],
+    }])
+
+    console.run_command(app, user, 'timeline', ['--once'])
+
+    mock_get.assert_called_once_with(app, user, '/api/v1/timelines/home?limit=10', None)
+
+    out, err = capsys.readouterr()
+    lines = out.split("\n")
+
+    assert "Frank Zappa" in lines[1]
+    assert "@fz" in lines[1]
+    assert "2017-04-12 15:53" in lines[1]
+
+    assert (
+        "The computer can't tell you the emotional story. It can give you the "
+        "exact mathematical design, but\nwhat's missing is the eyebrows." in out)
+
+    assert "111111111111111111" in lines[-3]
+    assert "↻ Reblogged \x1b[34m@jc\x1b[0m" in lines[-3]
+
+    assert err == ""
+
+
+@mock.patch('toot.http.get')
+def test_thread(mock_get, monkeypatch, capsys):
+    mock_get.side_effect = [
+        MockResponse({
+            'id': '111111111111111111',
+            'account': {
+                'display_name': 'Frank Zappa',
+                'acct': 'fz'
+            },
+            'created_at': '2017-04-12T15:53:18.174Z',
+            'content': "my response in the middle",
+            'reblog': None,
+            'in_reply_to_id': '111111111111111110',
+            'media_attachments': [],
+        }),
+        MockResponse({
+            'ancestors': [{
+                'id': '111111111111111110',
+                'account': {
+                    'display_name': 'Frank Zappa',
+                    'acct': 'fz'
+                },
+                'created_at': '2017-04-12T15:53:18.174Z',
+                'content': "original content",
+                'media_attachments': [],
+                'reblog': None,
+                'in_reply_to_id': None}],
+            'descendants': [{
+                'id': '111111111111111112',
+                'account': {
+                    'display_name': 'Frank Zappa',
+                    'acct': 'fz'
+                },
+                'created_at': '2017-04-12T15:53:18.174Z',
+                'content': "response message",
+                'media_attachments': [],
+                'reblog': None,
+                'in_reply_to_id': '111111111111111111'}],
+        }),
+    ]
+
+    console.run_command(app, user, 'thread', ['111111111111111111'])
+
+    calls = [
+        mock.call(app, user, '/api/v1/statuses/111111111111111111'),
+        mock.call(app, user, '/api/v1/statuses/111111111111111111/context'),
+    ]
+    mock_get.assert_has_calls(calls, any_order=False)
+
+    out, err = capsys.readouterr()
+
+    assert not err
+
+    # Display order
+    assert out.index('original content') < out.index('my response in the middle')
+    assert out.index('my response in the middle') < out.index('response message')
+
+    assert "original content" in out
+    assert "my response in the middle" in out
+    assert "response message" in out
     assert "Frank Zappa" in out
     assert "@fz" in out
+    assert "111111111111111111" in out
+    assert "In reply to" in out
 
+@mock.patch('toot.http.get')
+def test_reblogged_by(mock_get, monkeypatch, capsys):
+    mock_get.return_value = MockResponse([{
+        'display_name': 'Terry Bozzio',
+        'acct': 'bozzio@drummers.social',
+    }, {
+        'display_name': 'Dweezil',
+        'acct': 'dweezil@zappafamily.social',
+    }])
+
+    console.run_command(app, user, 'reblogged_by', ['111111111111111111'])
+
+    calls = [
+        mock.call(app, user, '/api/v1/statuses/111111111111111111/reblogged_by'),
+    ]
+    mock_get.assert_has_calls(calls, any_order=False)
+
+    out, err = capsys.readouterr()
+
+    # Display order
+    expected = "\n".join([
+        "Terry Bozzio",
+        " @bozzio@drummers.social",
+        "Dweezil",
+        " @dweezil@zappafamily.social",
+        "",
+    ])
+    assert out == expected
 
 @mock.patch('toot.http.post')
 def test_upload(mock_post, capsys):
