@@ -7,6 +7,7 @@ from urllib.parse import urlparse, urlencode, quote
 
 from toot import http, CLIENT_NAME, CLIENT_WEBSITE
 from toot.exceptions import AuthenticationError
+from toot.utils import str_bool
 
 SCOPES = 'read write follow'
 
@@ -106,7 +107,7 @@ def post_status(
         'status': status,
         'media_ids[]': media_ids,
         'visibility': visibility,
-        'sensitive': "true" if sensitive else "false",
+        'sensitive': str_bool(sensitive),
         'spoiler_text': spoiler_text,
         'in_reply_to_id': in_reply_to_id,
     }, headers=headers).json()
@@ -144,27 +145,19 @@ def unpin(app, user, status_id):
     return _status_action(app, user, status_id, 'unpin')
 
 
-def timeline_home(app, user):
-    return http.get(app, user, '/api/v1/timelines/home').json()
+def context(app, user, status_id):
+    url = '/api/v1/statuses/{}/context'.format(status_id)
 
-
-def timeline_public(app, user, local=False):
-    params = {'local': 'true' if local else 'false'}
-    return http.get(app, user, '/api/v1/timelines/public', params).json()
-
-
-def timeline_tag(app, user, hashtag, local=False):
-    url = '/api/v1/timelines/tag/{}'.format(quote(hashtag))
-    params = {'local': 'true' if local else 'false'}
-    return http.get(app, user, url, params).json()
-
-
-def timeline_list(app, user, list_id):
-    url = '/api/v1/timelines/list/{}'.format(list_id)
     return http.get(app, user, url).json()
 
 
-def get_next_path(headers):
+def reblogged_by(app, user, status_id):
+    url = '/api/v1/statuses/{}/reblogged_by'.format(status_id)
+
+    return http.get(app, user, url).json()
+
+
+def _get_next_path(headers):
     """Given timeline response headers, returns the path to the next batch"""
     links = headers.get('Link', '')
     matches = re.match('<([^>]+)>; rel="next"', links)
@@ -173,19 +166,19 @@ def get_next_path(headers):
         return "?".join([parsed.path, parsed.query])
 
 
-def _timeline_generator(app, user, path, limit=20):
+def _timeline_generator(app, user, path, params=None):
     while path:
-        response = http.get(app, user, path)
+        response = http.get(app, user, path, params)
         yield response.json()
-        path = get_next_path(response.headers)
+        path = _get_next_path(response.headers)
 
 
-def _anon_timeline_generator(instance, path, limit=20):
+def _anon_timeline_generator(instance, path, params=None):
     while path:
         url = "https://{}{}".format(instance, path)
-        response = http.anon_get(url, path)
+        response = http.anon_get(url, params)
         yield response.json()
-        path = get_next_path(response.headers)
+        path = _get_next_path(response.headers)
 
 
 def home_timeline_generator(app, user, limit=20):
@@ -193,9 +186,21 @@ def home_timeline_generator(app, user, limit=20):
     return _timeline_generator(app, user, path)
 
 
-def public_timeline_generator(instance, limit=20):
-    path = '/api/v1/timelines/public?limit={}'.format(limit)
-    return _anon_timeline_generator(instance, path)
+def public_timeline_generator(instance, local=False, limit=20):
+    path = '/api/v1/timelines/public'
+    params = {'local': str_bool(local), 'limit': limit}
+    return _anon_timeline_generator(instance, path, params)
+
+
+def tag_timeline_generator(instance, hashtag, local=False, limit=20):
+    path = '/api/v1/timelines/tag/{}'.format(hashtag)
+    params = {'local': str_bool(local), 'limit': limit}
+    return _anon_timeline_generator(instance, path, params)
+
+
+def timeline_list_generator(app, user, list_id, limit=20):
+    path = '/api/v1/timelines/list/{}'.format(list_id)
+    return _timeline_generator(app, user, path, {'limit': limit})
 
 
 def upload_media(app, user, file):
@@ -245,6 +250,12 @@ def verify_credentials(app, user):
     return http.get(app, user, '/api/v1/accounts/verify_credentials').json()
 
 
+def single_status(app, user, status_id):
+    url = '/api/v1/statuses/{}'.format(status_id)
+
+    return http.get(app, user, url).json()
+
+
 def get_notifications(app, user):
     return http.get(app, user, '/api/v1/notifications').json()
 
