@@ -4,15 +4,27 @@ import os
 import re
 import socket
 import unicodedata
+import warnings
 
 from bs4 import BeautifulSoup
 
 from toot.exceptions import ConsoleError
 
 
+def str_bool(b):
+    """Convert boolean to string, in the way expected by the API."""
+    return "true" if b else "false"
+
+
 def get_text(html):
     """Converts html to text, strips all tags."""
-    text = BeautifulSoup(html.replace('&apos;', "'"), "html.parser").get_text()
+
+    # Ignore warnings made by BeautifulSoup, if passed something that looks like
+    # a file (e.g. a dot which matches current dict), it will warn that the file
+    # should be opened instead of passing a filename.
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        text = BeautifulSoup(html.replace('&apos;', "'"), "html.parser").get_text()
 
     return unicodedata.normalize('NFKC', text)
 
@@ -63,14 +75,6 @@ def assert_domain_exists(domain):
         raise ConsoleError("Domain {} not found".format(domain))
 
 
-def trunc(text, length):
-    """Trims text to given length, if trimmed appends ellipsis."""
-    if len(text) <= length:
-        return text
-
-    return text[:length - 1] + '…'
-
-
 EOF_KEY = "Ctrl-Z" if os.name == 'nt' else "Ctrl-D"
 
 
